@@ -12,21 +12,18 @@ from tfx.proto import example_gen_pb2, trainer_pb2, \
 from ml_metadata.proto import metadata_store_pb2
 
 from tfx.dsl.experimental import latest_blessed_model_resolver
-from tfx.utils.dsl_utils import csv_input, tfrecord_input, external_input
 
 from tfx.components.base.base_component import BaseComponent
 
 from tfx.components import CsvExampleGen, ImportExampleGen, \
     StatisticsGen, SchemaGen, Transform, ExampleValidator, ImporterNode, \
-    ResolverNode, Trainer, Evaluator, InfraValidator, Pusher, BulkInferrer
+    ResolverNode, Trainer, Evaluator, InfraValidator, Pusher, BulkInferrer, Tuner
 
-from tfx.components import BigQueryExampleGen
+from tfx.extensions.google_cloud_big_query.example_gen.component import BigQueryExampleGen
 
 from tfx.components.base import executor_spec
 from tfx.components.trainer import executor as trainer_executor
 
-from tfx.components.tuner.component import Tuner
-
 from tfx.types import standard_artifacts, Channel
 from tfx.extensions.google_cloud_ai_platform.trainer \
     import executor as ai_platform_trainer_executor
@@ -146,7 +143,7 @@ class PipelineDef:
     def from_csv(self, uri: Text,
                  input_config: Optional[example_gen_pb2.Input] = None,
                  output_config: Optional[example_gen_pb2.Output] = None):
-        """Constructs a CsvExampleGen component by using external_input(uri)
+        """Constructs a CsvExampleGen component by using `uri`
 
         Args:
             uri (Text): Csv file(s) uri
@@ -164,7 +161,7 @@ class PipelineDef:
     def from_tfrecord(self, uri: Text,
                       input_config: Optional[example_gen_pb2.Input] = None,
                       output_config: Optional[example_gen_pb2.Output] = None):
-        """Constructs an ImportExampleGen component by using external_input(uri)
+        """Constructs an ImportExampleGen component by using `uri`
 
         Args:
             uri (Text): TFRecord file(s) uri
@@ -181,7 +178,7 @@ class PipelineDef:
     def from_bigquery(self, query: Text,
                       input_config: Optional[example_gen_pb2.Input] = None,
                       output_config: Optional[example_gen_pb2.Output] = None):
-        """Constructs a BigQueryExampleGen component by using external_input(uri)
+        """Constructs a BigQueryExampleGen component by using `uri`
 
         Args:
             query (Text): The query to run
@@ -262,7 +259,7 @@ class PipelineDef:
         return self.schema_gen
 
     @build_step('example_validator')
-    def validate_input_data(self):
+    def validate_input_data(self, exclude_splits: Optional[List[Text]] = None):
         """Constructs an ExampleValidator component that uses a schema and the output
         of StatisticsGen via `generate_statistics` to validate input data.
 
@@ -272,14 +269,17 @@ class PipelineDef:
         """
         args = {
             'statistics': self.statistics_gen.outputs['statistics'],
-            'schema': SchemaInputs.SCHEMA_CHANNEL(self)
+            'schema': SchemaInputs.SCHEMA_CHANNEL(self),
         }
 
+        if exclude_splits:
+            args['exclude_splits'] = exclude_splits
+
         self.example_validator = ExampleValidator(**args)
         return self.example_validator
 
     @build_step('transform')
-    def preprocess(self, module_file: Union[Text, data_types.RuntimeParameter]):
+    def preprocess(self, module_file: Union[Text, data_types.RuntimeParameter], materialize: bool = True):
         """Constructs a Transform component using examples generated and a schema.
 
         If a user provided schema is specified, it will be used.
@@ -294,7 +294,8 @@ class PipelineDef:
         args = {
             'examples': self.example_gen.outputs['examples'],
             'module_file': module_file,
-            'schema': SchemaInputs.SCHEMA_CHANNEL(self)
+            'schema': SchemaInputs.SCHEMA_CHANNEL(self),
+            'materialize': materialize
         }
 
         self.transform = Transform(**args)
@@ -398,8 +399,11 @@ class PipelineDef:
         if hparams:
             args['hyperparameters'] = hparams
 
-        args['custom_executor_spec'] = custom_executor_spec or \
-            executor_spec.ExecutorClassSpec(trainer_executor.GenericExecutor)
+        if not custom_executor_spec:
+            custom_executor_spec = executor_spec.ExecutorClassSpec(
+                trainer_executor.GenericExecutor)
+
+        args['custom_executor_spec'] = custom_executor_spec
 
         if custom_config:
             args['custom_config'] = custom_config
